{% extends "site_base.html" %}

{% load i18n %}

{% block metas %}
    <title>{{ _('Log out') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Log out') }}</li>
  </ul>

	<div class="alert alert-success">
	  <button type="button" class="close" data-dismiss="alert">×</button>
	  {% trans "You have signed out." %}
	</div>

</section>
{% endblock %}
