{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block metas %}
    <title>{% if token_fail %}{% trans "Bad Token" %}{% else %}{% trans "Change Password" %}{% endif %} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {% if token_fail %}{% trans "Bad Token" %}{% else %}{% trans "Change Password" %}{% endif %}</li>
  </ul>


    {% if token_fail %}
        {% url 'account_reset_password' as passwd_reset_url %}
        <p>{% blocktrans %}The password reset link was invalid, possibly because it has already been used.  Please request a <a href="{{ passwd_reset_url }}">new password reset</a>.{% endblocktrans %}</p>
    {% else %}
        {% if form %}
            <form method="POST" action="" class="uniForm offset3 form-horizontal">
                {% csrf_token %}
                {{ form.as_p }}
                <input type="submit" name="action" value="{% trans "change password" %}" class="btn btn-info"/>
            </form>
        {% else %}
            <div clas="alert alert-success">{% trans 'Your password is now changed.' %}</div>
        {% endif %}
    {% endif %}

</section>
{% endblock %}
